@@ -17,13 +17,16 @@ def thumbnailer():
 
 @thumbnailer.command()
 @click.argument("ids", nargs=-1)
-def process(ids: tuple[str]):
+@click.option("-o", "--offset", type=int, default=0)
+def process(ids: tuple[str], offset: int):
     """Create thumbnails for the given/all resources
     """
     user = tk.get_action("get_site_user")({"ignore_auth": True}, {})
     resources = _get_resources(ids)
     with click.progressbar(resources, length=resources.count()) as bar:
-        for res in bar:
+        for step, res in enumerate(bar):
+            if step < offset:
+                continue
             utils.create_thumbnail({"user": user["name"]}, {
                 "id": res.id,
                 "format": res.format,
@@ -32,7 +35,7 @@ def process(ids: tuple[str]):
 def _get_resources(ids: tuple[str]):
     q = model.Session.query(model.Resource).filter(
         model.Resource.state == "active"
-    )
+    ).order_by(model.Resource.id)
     if ids:
         q = q.filter(model.Resource.id.in_(ids))
 
